<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:output method="xml" encoding="UTF-8" />
    
  <!-- Default stage table names -->
  <xsl:variable name="ST_CUSTOM_FIELDS">DS_CUSTOM_FIELDS</xsl:variable>
  <!-- Joined Tables -->
  <xsl:variable name="ST_CUSTOM_FIELD_JOIN_VALUES">DS_CUSTOM_FIELD_JOIN_VALUES</xsl:variable>
  
  <!-- Staging Field names -->
  <xsl:variable name="custom_field_name_field">custom_field_name</xsl:variable>
  <xsl:variable name="custom_field_type_field">custom_field_type</xsl:variable>
  <xsl:variable name="custom_field_mandatory_field">custom_field_mandatory</xsl:variable>
  <xsl:variable name="custom_field_max_field">custom_field_max_type</xsl:variable>
  <xsl:variable name="custom_field_min_field">custom_field_min_type</xsl:variable>
  <xsl:variable name="field_values_field">field_values</xsl:variable>
  
  <!-- Custom Field.. Table Level -->
  <xsl:template match="custom_field">
    <bean>
      <xsl:attribute name="class">
        <xsl:call-template name="choose_table_synchronizer_class"/>
      </xsl:attribute>
      <xsl:call-template name="inject_staging_datasource" />
      <xsl:call-template name="choose_staging_table_name">
        <xsl:with-param name="default_name" select="$ST_CUSTOM_FIELDS" />
      </xsl:call-template>
      <property name="dataSynchronizationService">
        <ref bean="dataSyncCustomFieldService" />
      </property>
      <xsl:call-template name="inject_report_keeper"/>
      <!-- Row Synchronizer -->
      <xsl:call-template name="row_synchronizer">
        <xsl:with-param name="data_synchronization_service">dataSyncCustomFieldService</xsl:with-param>
        <xsl:with-param name="default_table" select="$ST_CUSTOM_FIELDS" />
        <xsl:with-param name="pre_commit_validator">customFieldPreCommitValidator</xsl:with-param>
      </xsl:call-template>
    </bean>
  </xsl:template>

  <!-- Custom Field .. Field Level -->
  <xsl:template match="custom_field_name">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">name</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="custom_field_type">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">enumType</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$customTypeTypeMapper" />
      <xsl:with-param name="validatorBean">customFieldTypeValidator</xsl:with-param>
    </xsl:call-template>
  </xsl:template>  
  
  <xsl:template match="custom_field_mandatory">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">mandatory</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$booleanTypeMapper" />
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template match="custom_field_max">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">max</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$nullableStringTypeMapper"/> 
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template match="custom_field_min">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">min</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$nullableStringTypeMapper"/> 
    </xsl:call-template>
  </xsl:template>
  
  <!-- Joined Table Field -->
  <xsl:template match="field_values">
    <entry>
      <xsl:attribute name="key">
        <xsl:value-of select="name()" />
      </xsl:attribute>
      <bean>
        <xsl:call-template name="core_field_properties">
          <xsl:with-param name="synchronizer_class" select="$collection_fieldsync_class"/>
          <xsl:with-param name="model_property_name">values</xsl:with-param>
          <xsl:with-param name="mapper_class" select="$hashSetTypeMapper"/>
        </xsl:call-template>

        <property name="joinedTableSynchronizer">
          <bean>
            <xsl:choose>
              <xsl:when test="@stage_table">
                <xsl:call-template name="joined_table_synchronizer">
                  <xsl:with-param name="joined_table_name" select="@stage_table"/>
                  <xsl:with-param name="parent_external_key">FIELD_EXTERNAL_KEY</xsl:with-param>
                  <xsl:with-param name="model_property_name">values</xsl:with-param>
                  <xsl:with-param name="child_external_key">FIELD_VALUE</xsl:with-param>
                </xsl:call-template>
              </xsl:when>
              <xsl:otherwise>
                <xsl:call-template name="joined_table_synchronizer">
                  <xsl:with-param name="joined_table_name" select="$ST_CUSTOM_FIELD_JOIN_VALUES"/>
                  <xsl:with-param name="parent_external_key">FIELD_EXTERNAL_KEY</xsl:with-param>
                  <xsl:with-param name="model_property_name">values</xsl:with-param>
                  <xsl:with-param name="child_external_key">FIELD_VALUE</xsl:with-param>
                </xsl:call-template>
              </xsl:otherwise>
            </xsl:choose>
          </bean>
        </property>
      </bean>
    </entry>
  </xsl:template>
 
</xsl:stylesheet>