<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="xml" encoding="UTF-8"
    doctype-system="http://www.springframework.org/dtd/spring-beans.dtd"
    doctype-public="-//SPRING//DTD BEAN//EN"
    cdata-section-elements="beans" />

  <!-- Default stage table names -->
	<xsl:variable name="ST_EMAIL">DS_EMAIL_DEVICES</xsl:variable>
	<xsl:variable name="ST_NUMERIC_PAGER">DS_NUMERIC_PAGER_DEVICES</xsl:variable>
	<xsl:variable name="ST_TEXT_PAGER">DS_TEXT_PAGER_DEVICES</xsl:variable>
	<xsl:variable name="ST_IM">DS_IM_DEVICES</xsl:variable>
	<xsl:variable name="ST_VOICE">DS_VOICE_DEVICES</xsl:variable>
	<xsl:variable name="ST_TEXT_PHONE">DS_TEXT_PHONE_DEVICES</xsl:variable>
	<xsl:variable name="ST_GENERIC_DEVICES">DS_GENERIC_DEVICES</xsl:variable>
	<xsl:variable name="ST_BES_DEVICES">DS_BES_DEVICES</xsl:variable>

  <!-- Staging Field names -->
	<xsl:variable name="delay_field">delay</xsl:variable>
	<xsl:variable name="device_name_field">device_name</xsl:variable>
	<xsl:variable name="default_device_field">default_device</xsl:variable>
	<xsl:variable name="is_two_way_field">is_two_way</xsl:variable>
	<xsl:variable name="user_key_field">user_key</xsl:variable>
	<xsl:variable name="service_provider_field">service_provider_name</xsl:variable>
	<xsl:variable name="sequence_field">device_order</xsl:variable>
	<xsl:variable name="country_code_field">country</xsl:variable>

	<!-- Row Synchronizers -->
	<xsl:variable name="device_row_synchronizer">com.invoqsystems.apex.datasynchronizer.processor.EnterpriseDeviceRowSynchronizerImpl</xsl:variable>
  
	<!-- Email -->
	<xsl:template match="email">
		<bean>
			<xsl:attribute name="class">
        <xsl:call-template name="choose_table_synchronizer_class"/>
			</xsl:attribute>
			<xsl:call-template name="inject_staging_datasource" />
			<xsl:call-template name="choose_staging_table_name">
			  <xsl:with-param name="default_name" select="$ST_EMAIL" />
			</xsl:call-template>
			<xsl:call-template name="include_audit_service" />
			<property name="dataSynchronizationService">
				<ref bean="dataSyncEmailService" />
			</property>
			<xsl:call-template name="inject_report_keeper"/>
			<!-- Row Synchronizer -->
			<xsl:call-template name="row_synchronizer">
				<xsl:with-param name="sync_class" select="$device_row_synchronizer"/>
				<xsl:with-param name="data_synchronization_service">dataSyncEmailService</xsl:with-param>
				<xsl:with-param name="default_table" select="$ST_EMAIL" />
			</xsl:call-template>
		</bean>
	</xsl:template>

	<!-- IM -->
	<xsl:template match="im">
		<bean>
			<xsl:attribute name="class">
        <xsl:call-template name="choose_table_synchronizer_class"/>
			</xsl:attribute>
			<xsl:call-template name="inject_staging_datasource" />
			<xsl:call-template name="choose_staging_table_name">
			  <xsl:with-param name="default_name" select="$ST_IM" />
			</xsl:call-template>
			<xsl:call-template name="include_audit_service" />
			<property name="dataSynchronizationService">
				<ref bean="dataSyncIMService" />
			</property>
			<xsl:call-template name="inject_report_keeper"/>
			<!-- Row Synchronizer -->
			<xsl:call-template name="row_synchronizer">
				<xsl:with-param name="sync_class" select="$device_row_synchronizer"/>
				<xsl:with-param name="data_synchronization_service">dataSyncIMService</xsl:with-param>
				<xsl:with-param name="default_table" select="$ST_IM" />
			</xsl:call-template>
		</bean>
	</xsl:template>

	<!-- TEXT_PAGER -->
	<xsl:template match="text_pager">
		<bean>
			<xsl:attribute name="class">
        <xsl:call-template name="choose_table_synchronizer_class"/>
			</xsl:attribute>
			<xsl:call-template name="inject_staging_datasource" />
			<xsl:call-template name="choose_staging_table_name">
			  <xsl:with-param name="default_name" select="$ST_TEXT_PAGER" />
			</xsl:call-template>
			<xsl:call-template name="include_audit_service" />
			<property name="dataSynchronizationService">
				<ref bean="dataSyncTextPagerService" />
			</property>
			<xsl:call-template name="inject_report_keeper"/>
			<!-- Row Synchronizer -->
			<xsl:call-template name="row_synchronizer">
				<xsl:with-param name="sync_class" select="$device_row_synchronizer"/>
				<xsl:with-param name="data_synchronization_service">dataSyncTextPagerService</xsl:with-param>
				<xsl:with-param name="default_table" select="$ST_TEXT_PAGER" />
			</xsl:call-template>
		</bean>
	</xsl:template>

	<!-- NUMERIC_PAGER -->
	<xsl:template match="numeric_pager">
		<bean>
			<xsl:attribute name="class">
        <xsl:call-template name="choose_table_synchronizer_class"/>
			</xsl:attribute>
			<xsl:call-template name="inject_staging_datasource" />
			<xsl:call-template name="choose_staging_table_name">
			  <xsl:with-param name="default_name" select="$ST_NUMERIC_PAGER" />
			</xsl:call-template>
			<xsl:call-template name="include_audit_service" />
			<property name="dataSynchronizationService">
				<ref bean="dataSyncNumericPagerService" />
			</property>
			<xsl:call-template name="inject_report_keeper"/>
			<!-- Row Synchronizer -->
			<xsl:call-template name="row_synchronizer">
				<xsl:with-param name="sync_class" select="$device_row_synchronizer"/>
				<xsl:with-param name="data_synchronization_service">dataSyncNumericPagerService</xsl:with-param>
				<xsl:with-param name="default_table" select="$ST_NUMERIC_PAGER" />
			</xsl:call-template>
		</bean>
	</xsl:template>

	<!-- VOICE -->
	<xsl:template match="voice">
		<bean>
			<xsl:attribute name="class">
        <xsl:call-template name="choose_table_synchronizer_class"/>
			</xsl:attribute>
			<xsl:call-template name="inject_staging_datasource" />
			<xsl:call-template name="choose_staging_table_name">
			  <xsl:with-param name="default_name" select="$ST_VOICE" />
			</xsl:call-template>
			<xsl:call-template name="include_audit_service" />
			<property name="dataSynchronizationService">
				<ref bean="dataSyncVoiceService" />
			</property>
			<xsl:call-template name="inject_report_keeper"/>
			<!-- Row Synchronizer -->
			<xsl:call-template name="row_synchronizer">
				<xsl:with-param name="sync_class" select="$device_row_synchronizer"/>
				<xsl:with-param name="data_synchronization_service">dataSyncVoiceService</xsl:with-param>
				<xsl:with-param name="default_table" select="$ST_VOICE" />
			</xsl:call-template>
		</bean>
	</xsl:template>

	<!-- TEXT_PHONE -->
	<xsl:template match="text_phone">
		<bean>
			<xsl:attribute name="class">
        <xsl:call-template name="choose_table_synchronizer_class"/>
			</xsl:attribute>
			<xsl:call-template name="inject_staging_datasource" />
			<xsl:call-template name="choose_staging_table_name">
			  <xsl:with-param name="default_name" select="$ST_TEXT_PHONE" />
			</xsl:call-template>
			<xsl:call-template name="include_audit_service" />
			<property name="dataSynchronizationService">
				<ref bean="dataSyncTextPhoneService" />
			</property>
			<xsl:call-template name="inject_report_keeper"/>
			<!-- Row Synchronizer -->
			<xsl:call-template name="row_synchronizer">
				<xsl:with-param name="sync_class" select="$device_row_synchronizer"/>
				<xsl:with-param name="data_synchronization_service">dataSyncTextPhoneService</xsl:with-param>
				<xsl:with-param name="default_table" select="$ST_TEXT_PHONE" />
			</xsl:call-template>
		</bean>
	</xsl:template>

	<!-- GENERIC -->
	<xsl:template match="generic_device">
		<bean>
			<xsl:attribute name="class">
        <xsl:call-template name="choose_table_synchronizer_class"/>
			</xsl:attribute>
			<xsl:call-template name="inject_staging_datasource" />
			<xsl:call-template name="choose_staging_table_name">
			  <xsl:with-param name="default_name" select="$ST_GENERIC_DEVICES" />
			</xsl:call-template>
			<xsl:call-template name="include_audit_service" />
			<property name="dataSynchronizationService">
				<ref bean="dataSyncGenericDeviceService" />
			</property>
			<xsl:call-template name="inject_report_keeper"/>
			<!-- Row Synchronizer -->
			<xsl:call-template name="row_synchronizer">
				<xsl:with-param name="sync_class" select="$device_row_synchronizer"/>
				<xsl:with-param name="data_synchronization_service">dataSyncGenericDeviceService</xsl:with-param>
				<xsl:with-param name="default_table" select="$ST_GENERIC_DEVICES" />
			</xsl:call-template>
		</bean>
	</xsl:template>

	<!-- BES -->
	<xsl:template match="bes_device">
		<bean>
			<xsl:attribute name="class">
        <xsl:call-template name="choose_table_synchronizer_class"/>
			</xsl:attribute>
			<xsl:call-template name="inject_staging_datasource" />
			<xsl:call-template name="choose_staging_table_name">
			  <xsl:with-param name="default_name" select="$ST_BES_DEVICES" />
			</xsl:call-template>
			<xsl:call-template name="include_audit_service" />
			<property name="dataSynchronizationService">
				<ref bean="dataSyncBESDeviceService" />
			</property>
			<xsl:call-template name="inject_report_keeper"/>
			<!-- Row Synchronizer -->
			<xsl:call-template name="row_synchronizer">
				<xsl:with-param name="sync_class" select="$device_row_synchronizer"/>
				<xsl:with-param name="data_synchronization_service">dataSyncBESDeviceService</xsl:with-param>
				<xsl:with-param name="default_table" select="$ST_BES_DEVICES" />
			</xsl:call-template>
		</bean>
	</xsl:template>

  <!-- Field Level -->
	<!-- Note that if no mapper class is specified then a match will be done on type, the default mapper is String -->
	<xsl:template match="user_key">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">owner</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$referenceKeyTypeMapper" />
      <xsl:with-param name="mapper_properties">dataSyncPersonService</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="device_name">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">deviceName</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$deviceNameTypeMapper" />
      <xsl:with-param name="mapper_properties">dataSyncDeviceNameService</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="service_provider_name">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">provider</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$referenceKeyTypeMapper" />
      <xsl:with-param name="mapper_properties">dataSyncServiceProviderService</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="default_device">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">emergencyDevice</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$booleanTypeMapper" />
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="device_order">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">sequence</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$integerTypeMapper" />
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="address">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">address</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="delay">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">delay</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$integerObjectTypeMapper" />
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="lock_24x7">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">lock24x7</xsl:with-param>
			<xsl:with-param name="mapper_class" select="$booleanTypeMapper" />
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="pin">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">pin</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="is_two_way">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">twoWay</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$booleanTypeMapper" />
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="country">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">country</xsl:with-param>
			<xsl:with-param name="mapper_class" select="$countryCodeTypeMapper"/>
      <xsl:with-param name="mapper_properties">dataSyncCountryService</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="area_code">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">areaCode</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="phone_number">
		<xsl:choose>
			<xsl:when test="translate(name(parent::node()),$uc,$lc)='numeric_pager'">
				<xsl:call-template name="call_fields">
					<xsl:with-param name="model_property_name">pagerNumber</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="call_fields">
					<xsl:with-param name="model_property_name">number</xsl:with-param>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="extension">
		<xsl:call-template name="call_fields">
            <xsl:with-param name="mapper_class" select="$nullableStringTypeMapper"/>
			<xsl:with-param name="model_property_name">extension</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

  <xsl:template match="country_code">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="mapper_class" select="$nullableStringTypeMapper"/>
      <xsl:with-param name="model_property_name">country</xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="target_number">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">phoneNumber</xsl:with-param>
    </xsl:call-template>
  </xsl:template>

</xsl:stylesheet>
