<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="xml" encoding="UTF-8"
    doctype-system="http://www.springframework.org/dtd/spring-beans.dtd"
    doctype-public="-//SPRING//DTD BEAN//EN"
    cdata-section-elements="beans" />

  <!-- Default stage table names -->
	<xsl:variable name="ST_GROUP">DS_GROUPS</xsl:variable>
	<xsl:variable name="ST_TEAM">DS_TEAMS</xsl:variable>

  <!-- Staging Field names -->
  <!-- group fields -->
	<xsl:variable name="supervisor_list_field">supervisor_list</xsl:variable>
	<xsl:variable name="observer_list_field">observer_list</xsl:variable>
  <!-- team fields -->
	<xsl:variable name="group_key_field">group_key</xsl:variable>
	<xsl:variable name="allow_duplicates_field">allow_duplicates</xsl:variable>
	<xsl:variable name="escalation_schedule_field">escalation_schedule</xsl:variable>
	<xsl:variable name="is_round_robin_field">is_round_robin</xsl:variable>
	<xsl:variable name="sub_target_name_field">sub_target_name</xsl:variable>
	<xsl:variable name="timezone_field">timezone</xsl:variable>
	<xsl:variable name="group_site_name_field">group_site_name</xsl:variable>
  <xsl:variable name="add_24x7_coverage_field">add_24x7_coverage</xsl:variable>
  <!-- shared fields -->
	<xsl:variable name="use_default_device_field">use_default_devices</xsl:variable>

	<!-- Row Synchronizers -->
	<xsl:variable name="group_row_synchronizer">com.invoqsystems.apex.datasynchronizer.processor.EnterpriseGroupRowSynchronizerImpl</xsl:variable>
	<xsl:variable name="team_row_synchronizer">com.invoqsystems.apex.datasynchronizer.processor.EnterpriseTeamRowSynchronizerImpl</xsl:variable>
  
	<!-- Group -->
	<xsl:template match="group">
		<bean>
			<xsl:attribute name="class">
        <xsl:call-template name="choose_table_synchronizer_class"/>
			</xsl:attribute>
			<xsl:call-template name="inject_staging_datasource" />
			<xsl:call-template name="choose_staging_table_name">
			  <xsl:with-param name="default_name" select="$ST_GROUP" />
			</xsl:call-template>
			<xsl:call-template name="include_audit_service" />
			<property name="dataSynchronizationService">
				<ref bean="dataSyncGroupService" />
			</property>
			<xsl:call-template name="inject_report_keeper"/>
			<!-- Row Synchronizer -->
			<xsl:call-template name="row_synchronizer">
				<xsl:with-param name="sync_class" select="$group_row_synchronizer"/>
				<xsl:with-param name="data_synchronization_service">dataSyncGroupService</xsl:with-param>
				<xsl:with-param name="default_table" select="$ST_GROUP" />
			</xsl:call-template>
		</bean>
	</xsl:template>

	<!-- Team -->
	<xsl:template match="team">
		<bean>
			<xsl:attribute name="class">
        <xsl:call-template name="choose_table_synchronizer_class"/>
			</xsl:attribute>
			<xsl:call-template name="inject_staging_datasource" />
			<xsl:call-template name="choose_staging_table_name">
			  <xsl:with-param name="default_name" select="$ST_TEAM" />
			</xsl:call-template>
			<xsl:call-template name="include_audit_service" />
			<property name="dataSynchronizationService">
				<ref bean="dataSyncTeamService" />
			</property>
			<xsl:call-template name="inject_report_keeper"/>
			<!-- Row Synchronizer -->
			<xsl:call-template name="row_synchronizer">
				<xsl:with-param name="sync_class" select="$team_row_synchronizer"/>
				<xsl:with-param name="data_synchronization_service">dataSyncTeamService</xsl:with-param>
				<xsl:with-param name="default_table" select="$ST_TEAM" />
			</xsl:call-template>
		</bean>
	</xsl:template>

  <!-- Field Level -->
	<!-- Note that if no mapper class is specified then a match will be done on type, the default mapper is String -->
	<xsl:template match="description">
      <xsl:call-template name="call_fields">
        <xsl:with-param name="mapper_class" select="$emptyStringTypeMapper"/>
	    <xsl:with-param name="model_property_name">description</xsl:with-param>
	  </xsl:call-template>
	</xsl:template>

	<xsl:template match="use_default_devices">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">useEmergencyDevice</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$booleanTypeMapper" />
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="group_name">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">targetName</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="timezone">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">timezone</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$referenceKeyTypeMapper" />
      <xsl:with-param name="mapper_properties">dataSyncTimeZoneService</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="group_site_name">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">site</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$referenceKeyTypeMapper" />
      <xsl:with-param name="mapper_properties">dataSyncSiteService</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="allow_duplicates">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">allowedDuplicates</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$booleanTypeMapper" />
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="supervisor_list">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="synchronizer_class" select="$enterprise_list_field_synchronizer"/>
			<xsl:with-param name="model_property_name">supervisors</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$listTypeMapper" />
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="observed_by_all">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">allRolesObserve</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$booleanTypeMapper" />
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="observer_list">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="synchronizer_class" select="$enterprise_list_field_synchronizer"/>
			<xsl:with-param name="model_property_name">observers</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$listTypeMapper" />
		</xsl:call-template>
	</xsl:template>

  <!-- team fields -->
	<xsl:template match="group_key">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">owner</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$referenceKeyTypeMapper" />
      <xsl:with-param name="mapper_properties">dataSyncGroupService</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="sub_target_name">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">subTargetName</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="escalation_schedule">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">escalationSchedule</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="is_round_robin">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">type</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$isRoundRobinTypeMapper" />
		</xsl:call-template>
	</xsl:template>

  <xsl:template match="add_24x7_coverage">
    <xsl:call-template name="call_fields">
			<xsl:with-param name="synchronizer_class" select="$enterprise_24x7_coverage_field_synchronizer"/>
      <xsl:with-param name="model_property_name">add_24x7_coverage</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$booleanTypeMapper" />
    </xsl:call-template>
  </xsl:template>

</xsl:stylesheet>
