<?xml version="1.0" encoding="UTF-8" ?>
<!DOCTYPE stylesheet [
  <!ENTITY space "<xsl:text> </xsl:text>">
  <!ENTITY cr "<xsl:text>
</xsl:text>">
]>

<xsl:stylesheet
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    exclude-result-prefixes="i18n">

  <xsl:strip-space elements="schedule-description group-schedules holiday-popup-holiday" />
  <xsl:preserve-space elements="schedule coverage team description schedule-shift-description member holiday-description holiday-repeating-pattern" />
  <xsl:output method="xml" omit-xml-declaration="yes"/>

  <xsl:template match="schedule-table[@view='monthly-view']">    
    <xsl:call-template name="schedule-table-legend" />
    <!-- Create the outer table which holds the monthly calendar and the expanded day schedule -->
    <table>
      <xsl:attribute name="class">table-monthly-view</xsl:attribute>
      <tr>
        <xsl:apply-templates />
      </tr>
    </table>
  </xsl:template>

  <xsl:template match="schedule-table[@view='monthly']">    
    <td>
      <!-- Add the monthly calendar with coverages -->
      <table>
        <xsl:attribute name="class">schedule-table-monthly-view</xsl:attribute>
        <xsl:apply-templates />
      </table>
    </td>
  </xsl:template>

  <xsl:template match="schedule-table[@view='expanded-daily-schedule']">   
    <td valign="top">
      <!-- Add the expanded day schedule -->
      <table>
        <xsl:attribute name="class">schedule-table-monthly-view</xsl:attribute>
        <xsl:apply-templates />
      </table>
    </td>
  </xsl:template>

  <xsl:template match="schedule-table-column-headers">
    <tr>
      <xsl:apply-templates select="schedule-table-column-header-filler"/>
      <xsl:apply-templates select="schedule-table-column-header"/>
    </tr>
  </xsl:template>

  <xsl:template match="schedule-table-column-header-filler">
    <th colspan="1" />
  </xsl:template>

  <xsl:template match="schedule-table-column-header">
    <th colspan="2">
      <xsl:if test="@class">
      	<xsl:attribute name="class"><xsl:value-of select="@class" /></xsl:attribute> 
      </xsl:if>
      <xsl:if test="@colspan">
      	<xsl:attribute name="colspan"><xsl:value-of select="@colspan" /></xsl:attribute> 
      </xsl:if>
      <xsl:if test="@style">
        <xsl:attribute name="style"><xsl:value-of select="@style" /></xsl:attribute>        
      </xsl:if>
      <xsl:if test="@nowrap">
        <xsl:attribute name="nowrap">true</xsl:attribute>        
      </xsl:if>
      <xsl:choose>
        <xsl:when test="@label">
          <xsl:value-of select="@label" />
        </xsl:when>
        <xsl:otherwise>
          <xsl:apply-templates />
        </xsl:otherwise>
      </xsl:choose>
    </th>
  </xsl:template>

  <xsl:template match="table-header-label">
    <xsl:value-of select="." />
  </xsl:template>

  <xsl:template match="schedule-table-row">
    <tr>
      <xsl:apply-templates />
    </tr>
  </xsl:template>

  <xsl:template match="date-range">
    <a>
      <xsl:if test="description">
        <xsl:attribute name="onmouseover">

          <xsl:text>$(this).xToolTip("</xsl:text>
         <xsl:apply-templates select="description" mode="pop-up" />
         <xsl:text>");</xsl:text>
        </xsl:attribute>

      </xsl:if>
      <xsl:if test="link-url">
        <xsl:attribute name="href"><xsl:value-of select="link-url/@uri" /></xsl:attribute>
      </xsl:if>
      <img height="14" alt="Coverage Shift" i18n:attr="alt">
        <xsl:attribute name="style">float: left;</xsl:attribute>
        <xsl:attribute name="src">/static/images/blue.png</xsl:attribute>
        <xsl:if test="@isOneTime='true'">
          <xsl:attribute name="style">cursor: default; float: left;</xsl:attribute>
          <xsl:attribute name="src">/static/images/green.png</xsl:attribute>
        </xsl:if>
        <xsl:if test="@isBeforeToday='true'">
          <xsl:attribute name="style">cursor: default; float: left;</xsl:attribute>
          <xsl:attribute name="src">/static/images/grey.png</xsl:attribute>
        </xsl:if>
        <xsl:attribute name="border">0</xsl:attribute>        
        <xsl:attribute name="width"><xsl:value-of select="duration-hours" /></xsl:attribute>
        <xsl:if test="@height">
          <xsl:attribute name="height">
            <xsl:value-of select="@height" />
          </xsl:attribute>
        </xsl:if>
      </img>
    </a>
  </xsl:template>
  <!--
     | Tried to link the entire table but it only works for Mozilla not IE
     | This is the only solution that works for both browsers.
     -->
  <xsl:template match="schedule-table-row-item[link-url]">
    <td class="row-item" colspan="2">
      <xsl:if test="not(coverage-level/@type='none')" >        
          <!-- not sure how to manage this when overlib is used -->
        <!-- xsl:attribute name="title"><xsl:apply-templates select="schedule-description" mode="pop-up"/></xsl:attribute -->
      </xsl:if>
      <table class="embedded-row-item">
        <xsl:if test="@onclick">
          <xsl:attribute name="href"><xsl:value-of select="link-url/@uri" /></xsl:attribute>
          <xsl:attribute name="id"><xsl:value-of select="link-url/@id" /></xsl:attribute>
          <xsl:attribute name="onclick">
            <xsl:text>window.location.href='</xsl:text><xsl:value-of select="@onclick" /><xsl:text>'</xsl:text>
          </xsl:attribute>
        </xsl:if>
        <xsl:if test="not(coverage-level/@type='none')" >
          <xsl:attribute name="onmouseover">
            <xsl:text>$(this).xToolTip("</xsl:text>
            <xsl:apply-templates select="schedule-description" mode="pop-up" />
            <xsl:text>");</xsl:text>
          </xsl:attribute>
        </xsl:if>
        <tr>
          <td class="top-left">
            <a>
              <xsl:attribute name="href"><xsl:value-of select="link-url/@uri" /></xsl:attribute>
              <xsl:value-of select="calendar-day" />
            </a>
          </td>
        </tr>
        <tr>
          <td class="bottom-right">
            <a>
              <xsl:attribute name="href"><xsl:value-of select="link-url/@uri" /></xsl:attribute>
              <xsl:apply-templates select="coverage-level" />
            </a>
          </td>
        </tr>
      </table>
    </td>
  </xsl:template>

  <xsl:template match="schedule-table-row-weekly-button">
    <td class="row-item" colspan="1">
      <xsl:apply-templates />
    </td>
  </xsl:template>

  <xsl:template match="schedule-table-row-item">
    <td class="row-item" colspan="2">
      <xsl:apply-templates />
    </td>
  </xsl:template>

  <xsl:template match="coverage-level">
    <img width="16" border="0" i18n:attr="alt">
      <xsl:choose>
        <xsl:when test="@type='full'">
          <xsl:attribute name="src">/static/images/full_coverage.gif</xsl:attribute>
          <xsl:attribute name="alt">Full Coverage</xsl:attribute>
        </xsl:when>
        <xsl:when test="@type='partial'">
          <xsl:attribute name="src">/static/images/partial_coverage.gif</xsl:attribute>
          <xsl:attribute name="alt">Partial Coverage</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="src">/static/images/no_coverage.gif</xsl:attribute>
          <xsl:attribute name="alt">No Coverage</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
    </img>
  </xsl:template>

  <xsl:template match="monthly-empty-table-row-item">
    <td class="empty-row-item" colspan="2">
      <xsl:text>&#160;</xsl:text>
    </td>
  </xsl:template>

  <xsl:template name="schedule-table-legend">
    <div style="margin-top: 30px;">        
      <span style="margin-right: 15px;">
        <em><i18n:text>Legend</i18n:text>:</em>
      </span>
      <span style="margin-right: 15px;">
        <img src="/static/images/full_coverage.gif" i18n:attr="alt">
          <xsl:attribute name="alt">Full Coverage</xsl:attribute>            
        </img>
    		<xsl:text>&#160;</xsl:text><i18n:text>Full coverage</i18n:text>
      </span>
      <span style="margin-right: 15px;">
        <img src="/static/images/partial_coverage.gif" i18n:attr="alt">
          <xsl:attribute name="alt">Partial Coverage</xsl:attribute>
        </img>
    		<xsl:text>&#160;</xsl:text><i18n:text>Partial coverage</i18n:text>
      </span>
      <span style="margin-right: 15px;">
        <img src="/static/images/no_coverage.gif" i18n:attr="alt">
          <xsl:attribute name="alt">No Coverage</xsl:attribute>            
        </img>
    		<xsl:text>&#160;</xsl:text><i18n:text>No coverage</i18n:text>
      </span>
    </div>
  </xsl:template>

  <xsl:template match="schedule-description">
    <xsl:apply-templates mode="monthly-schedule" />
  </xsl:template>

  <xsl:template match="expanded-daily-schedule"> 
    <td>
    <div style="height:46px;" />
    <!-- create the right hand schedule table -->
      <table class="DOM-expanded-details">
        <tr>
          <td class="daily-view-header" colspan='3'>
            <xsl:apply-templates select="expanded-daily-schedule-date" />
          </td>
        </tr>
        <xsl:apply-templates select="daily-schedules" mode="daily-schedule"/>
      </table>
      <div style="height:46px; width: 382px;">
        <xsl:apply-templates select="daily-schedules/daily-schedule-contains-rotation" mode="daily-schedule"/>
      </div>
    </td>
  </xsl:template>

  <xsl:template match="daily-schedule-contains-rotation"  mode="daily-schedule">
    <span style="height:46px; width: 382px;">
      <i><i18n:text>The rotation order displayed for rotating team members is for the current date; for future rotation orders, use the Weekly View</i18n:text>.</i>
    </span>
  </xsl:template>

  <xsl:template match="line-limit"> 
    <tr>
      <td class="daily-view-team" colspan='2'>
        <xsl:value-of select="normalize-space(.)" />
      </td>
    </tr>
  </xsl:template>

  <xsl:template match="expanded-daily-schedule-no-data"> 
    <td>
    <!-- create the right hand schedule table -->
    <table class="DOM-expanded-details">
      <div style="height:46px" />
      <tr>
        <td class="daily-view-header" colspan='3'>
          <xsl:apply-templates />
        </td>
      </tr>
    </table>
    </td>
  </xsl:template>

  <xsl:template match="expanded-daily-schedule-date">
    <xsl:value-of select="normalize-space(.)" />
  </xsl:template>

  <xsl:template match="schedule-description" mode="pop-up">
    <!-- this was based on the Ent 2.2 source -->
    <xsl:text>&#60;table class=\'hover-schedule-monthly\'&#62;</xsl:text>
      <xsl:apply-templates select="coverage" mode="pop-up" />
      <xsl:text>&#60;tr&#62;</xsl:text>
      <xsl:text>&#60;td class=\'subheader\'&#62;"+LBL_Schedules['DELAY']+"&#60;/td&#62;</xsl:text>
      <xsl:text>&#60;td class=\'subheader\'&#62;"+LBL_Schedules['TYPE']+"&#60;/td&#62;</xsl:text>
      <xsl:text>&#60;td class=\'subheader\'&#62;"+LBL_Schedules['NAME']+"&#60;/td&#62;</xsl:text>
      <xsl:text>&#60;td class=\'subheader\'&#62;"+LBL_Schedules['SHIFT']+"&#60;/td&#62;</xsl:text>
      <xsl:text>&#60;/tr&#62;</xsl:text>
      <xsl:apply-templates select="daily-schedules" mode="pop-up" />
    <xsl:text>&#60;/table&#62;</xsl:text>    
  </xsl:template>
      
  <xsl:template match="daily-schedules" mode="daily-schedule">
    <xsl:apply-templates select="schedule" mode="daily-schedule"/>
    <xsl:apply-templates select="line-limit"/>
  </xsl:template>

  <xsl:template match="schedule" mode="daily-schedule">
    <xsl:apply-templates select="team" mode="daily-schedule"/>
    <xsl:apply-templates select="temporary-replacements" mode="daily-schedule"/>
  </xsl:template>

  <xsl:template match="team" mode="daily-schedule">
    <xsl:apply-templates mode="daily-schedule" />
  </xsl:template>

  <xsl:template match="temporary-replacements" mode="daily-schedule">
    <xsl:apply-templates select ="temporary-replacements-header" />
    <xsl:apply-templates select ="temporary-replacement" mode="daily-schedule"/>
  </xsl:template>

  <xsl:template match="temporary-replacement" mode="daily-schedule">
    <xsl:apply-templates select="replacement-period" mode="daily-schedule" />
    <xsl:apply-templates select="replacement-content" mode="daily-schedule" />
  </xsl:template>

  <xsl:template match="temporary-replacements-header" >
    <tr>
      <td class='subheader' colspan='3'>
        <xsl:value-of select="." />
      </td>
    </tr>
  </xsl:template>

  <xsl:template match="replacement-period" mode="daily-schedule">
      <tr>
        <td class='header' colspan='3'>
        <xsl:apply-templates select="date-range" mode="replacement-period" />
      </td>
    </tr>
  </xsl:template>

  <xsl:template match="replacement-content" mode="daily-schedule">
    <tr>
      <td>
         <xsl:apply-templates select="delay" />
      </td>
      <td>
         <xsl:apply-templates select="type" />
      </td>
      <td>
        <xsl:apply-templates select="vacation-replacement" mode="daily-schedule" />
      </td>
    </tr>
  </xsl:template>

  <xsl:template match="vacation-replacement" mode="daily-schedule">
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="vacation-replacement" mode="pop-up">
    <xsl:apply-templates select="replacement" />
    <xsl:apply-templates select="vacation-replacement-for" />
    <xsl:apply-templates select="daily-schedule-vacationer" mode="pop-up" />
  </xsl:template>

  <xsl:template match="team-name" mode="daily-schedule">
    <tr>
      <td class='daily-view-team' colspan='3'>
        <xsl:apply-templates select="." /><xsl:text> (</xsl:text><xsl:apply-templates select="../../coverage" mode="daily-schedule"/><xsl:text>)</xsl:text>
      </td>
    </tr>
    <tr>
      <td class='daily-view-column-heading'><i18n:text>Esc</i18n:text></td>
      <td class='daily-view-column-heading'><i18n:text>Type</i18n:text></td>
      <td class='daily-view-column-heading'><i18n:text>Name</i18n:text></td>
    </tr>
  </xsl:template>

  <xsl:template match="member" mode="daily-schedule">    
    <tr>
      <td>
         <xsl:apply-templates select="delay" />
      </td>
      <td>
         <xsl:apply-templates select="type" />
      </td>
      <td class="display-name">
        <div class="display-name">
          <xsl:apply-templates select="name" /><xsl:text>&#32;</xsl:text><b><xsl:apply-templates select="company-name" /></b>
        </div>
      </td>
    </tr>  
  </xsl:template>

  <xsl:template match="daily-schedules" mode="pop-up">
    <xsl:apply-templates select="schedule" mode="pop-up"/>
    <xsl:apply-templates select="hasMoreSchedules" mode="monthly-pop-up"/>
  </xsl:template>

  <xsl:template match="schedule" mode="pop-up">
    <xsl:apply-templates select="team" mode="monthly-pop-up"/>
  </xsl:template>

  <xsl:template match="coverage" mode="monthly-pop-up">
    <td class="pop-up">
      <strong><xsl:apply-templates mode="coverage" /></strong>
    </td>
  </xsl:template>

  <xsl:template match="team" mode="monthly-pop-up">
    <xsl:apply-templates mode="monthly-pop-up" />
  </xsl:template>

  <xsl:template match="team-name" mode="monthly-pop-up">
    <xsl:text>&#60;tr&#62;</xsl:text>
      <xsl:text>&#60;td class=\'header\' colspan=\'5\'&#62;</xsl:text>
        <xsl:apply-templates select="." />
      <xsl:text>&#60;/td&#62;</xsl:text>
    <xsl:text>&#60;/tr&#62;</xsl:text>
  </xsl:template>

  <xsl:template match="member" mode="monthly-pop-up">    
    <xsl:text>&#60;tr&#62;</xsl:text>
      <xsl:text>&#60;td&#62;</xsl:text>
         <xsl:apply-templates select="delay" />
      <xsl:text>&#60;/td&#62;</xsl:text>
      <xsl:text>&#60;td&#62;</xsl:text>
        <xsl:apply-templates select="type" />
      <xsl:text>&#60;/td&#62;</xsl:text>
      <xsl:text>&#60;td&#62;</xsl:text>
        <xsl:apply-templates select="name" />
      <xsl:text>&#60;/td&#62;</xsl:text>
      <xsl:text>&#60;td&#62;</xsl:text>
        <xsl:apply-templates select="../../coverage" mode="monthly-pop-up" />
      <xsl:text>&#60;/td&#62;</xsl:text>
    <xsl:text>&#60;/tr&#62;</xsl:text>    
  </xsl:template>

  <xsl:template match="hasMoreMembers" mode="monthly-pop-up" >
    <xsl:text>&#60;tr&#62;</xsl:text>
      <xsl:text>&#60;td colspan=\'5\'&#62;</xsl:text>
        <xsl:text>...</xsl:text>
      <xsl:text>&#60;/td&#62;</xsl:text>
    <xsl:text>&#60;/tr&#62;</xsl:text>
  </xsl:template>

  <xsl:template match="hasMoreSchedules" mode="monthly-pop-up" >
    <xsl:text>&#60;tr&#62;</xsl:text>
      <xsl:text>&#60;td colspan=\'5\'&#62;</xsl:text>
        <xsl:text>... ... ...</xsl:text>
      <xsl:text>&#60;/td&#62;</xsl:text>
    <xsl:text>&#60;/tr&#62;</xsl:text>
  </xsl:template>

  <!--<xsl:template match="schedule-table[@view='weekly']">
    <table>
      <xsl:attribute name="id">schedule-table-weekly-view</xsl:attribute>
      <xsl:apply-templates mode="weekly-view"/>
    </table>
  </xsl:template>-->

  <xsl:template match="table-caption" mode="weekly-view">
    <caption>
      <xsl:apply-templates />
    </caption>
  </xsl:template>

  <xsl:template match="schedule-table-column-headers" mode="weekly-view">
    <!--<tr>-->
    <th colspan="2">
      <table class="embedded-row-item">
        <xsl:apply-templates select="." mode="embedded-table" />
      </table>
    </th>
    <!--</tr>-->
  </xsl:template>

  <xsl:template match="schedule-table-column-headers" mode="embedded-table">
    <tr>
      <xsl:apply-templates select="schedule-table-column-header" />
    </tr>
    <xsl:apply-templates select="schedule-table-column-headers" mode="ampm" />
  </xsl:template>

  <xsl:template match="schedule-table-column-headers" mode="ampm">
    <tr>
      <xsl:apply-templates select="schedule-table-column-header" mode="ampm" />
    </tr>
  </xsl:template>

  <xsl:template match="schedule-table-column-header" mode="ampm">
    <td class="am-header">AM</td>
    <td class="pm-header">PM</td>
  </xsl:template>

  <!-- TODO: make this div tag collapsible -->
  <xsl:template match="schedule-table-collapsible-rows" mode="weekly-view">
    <div>
      <xsl:apply-templates mode="weekly-view" />
    </div>
  </xsl:template>

  <xsl:template match="schedule-table-row[@type='label']" mode="weekly-view">
    <tr>
      <xsl:apply-templates mode="weekly-view" />
    </tr>
  </xsl:template>

  <xsl:template match="schedule-table-row" mode="weekly-view">
    <tr>
      <xsl:choose>
        <xsl:when test="schedule-table-row-item">
          <xsl:apply-templates mode="weekly-view" />
        </xsl:when>
        <xsl:otherwise>
          <xsl:apply-templates />
        </xsl:otherwise>
      </xsl:choose>
    </tr>
  </xsl:template>

  <xsl:template match="schedule-table-row-item" mode="weekly-view">
    <td class="row-item">
      <xsl:apply-templates />
    </td>
  </xsl:template>

  <xsl:template match="schedule-table-row-header" mode="weekly-view">
    <td class="row-header" colspan="2">
      <xsl:value-of select="@label" />
    </td>
  </xsl:template>

  <xsl:template match="empty-table-row-item" mode="weekly-view">
    <td class="row-item" colspan="2">
      <xsl:text>&#160;</xsl:text>
    </td>
  </xsl:template>

  <xsl:template match="schedule-shift">
    <a>
      <xsl:if test="description">
        <xsl:attribute name="onmouseover">
         <xsl:text>$(this).xToolTip("</xsl:text>
         <xsl:apply-templates select="description" mode="pop-up" />
         <xsl:text>");</xsl:text>
        </xsl:attribute>

      </xsl:if>
      <xsl:if test="@onmouseout">
        <xsl:attribute name="onmouseout"><xsl:value-of select="@onmouseout" /></xsl:attribute>
      </xsl:if>      
      <xsl:choose>
        <xsl:when test="link-url">
          <xsl:attribute name="href"><xsl:value-of select="link-url/@uri" /></xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="class">withouturl</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <img alt="Coverage Shift" i18n:attr="alt">
        <xsl:attribute name="style">float: left;</xsl:attribute>
        <xsl:choose>
          <xsl:when test="@isBeforeToday='true'">
            <xsl:attribute name="src">/static/images/lightgrey.png</xsl:attribute>
          </xsl:when>
          <xsl:when test="@isOneTime='true'">
            <xsl:attribute name="src">/static/images/lightgreen.png</xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="src">/static/images/lightblue.png</xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:attribute name="border">0</xsl:attribute>
        <!-- not sure how to manage this when overlib is used -->
        <!--xsl:attribute name="title"><xsl:apply-templates select="description" mode="text"/></xsl:attribute-->
        <xsl:attribute name="width"><xsl:value-of select="duration-hours" /></xsl:attribute>
        <xsl:attribute name="height">14</xsl:attribute>
      </img>
    </a>
  </xsl:template>

  <xsl:template match="schedule-shift-gap">
    <img height="14" alt="" title="">
      <xsl:attribute name="style">float: left;</xsl:attribute>
      <xsl:attribute name="src">/static/images/filler.gif</xsl:attribute>
      <xsl:attribute name="border">0</xsl:attribute>
      <xsl:attribute name="width"><xsl:value-of select="duration-hours" /></xsl:attribute>
      <xsl:if test="@height">
        <xsl:attribute name="height"><xsl:value-of select="@height" /></xsl:attribute>
      </xsl:if>
    </img>
  </xsl:template>

  <xsl:template match="description" mode="text" >
    <xsl:apply-templates select="schedule-shift-description" mode="text"/>
  </xsl:template>

  <xsl:template match="schedule-shift-description" mode="text" >
    <xsl:apply-templates select="coverage" mode="text" />
    &cr;
    <xsl:apply-templates select="team" mode="text" />
  </xsl:template>

  <xsl:template match="coverage" mode="text">
    <xsl:apply-templates mode="coverage"/>
  </xsl:template>

  <xsl:template match="team" mode="text">
    <xsl:apply-templates mode="text" />
  </xsl:template>

  <xsl:template match="member" mode="text">
    <xsl:apply-templates select="delay" />
    <xsl:text>&#32;-&#32;</xsl:text>
    <xsl:apply-templates select="type" />
    <xsl:text>&#32;-&#32;</xsl:text>
    <xsl:apply-templates select="name" />
    &cr;
  </xsl:template>

  <xsl:template match="description[parent::date-range/@isOneTime='true']" mode="pop-up" >
    <!-- this was based on the Ent 2.2 source -->
    <xsl:text>&#60;table class=\'hover-schedule\'&#62;</xsl:text>
    <xsl:text>&#60;tr&#62;</xsl:text>
      <xsl:text>&#60;td class=\'header\' colspan=\'4\'&#62;"+LBL_Schedules['IMPORTANT_NOTE']+"&#60;/td&#62;</xsl:text>
    <xsl:text>&#60;/tr&#62;</xsl:text>
    <xsl:text>&#60;tr&#62;</xsl:text>
      <xsl:text>&#60;td colspan=\'4\'&#62;</xsl:text>        
        <xsl:value-of select="normalize-space(.)" />
      <xsl:text>&#60;/td&#62;</xsl:text>
    <xsl:text>&#60;/tr&#62;</xsl:text>
    <xsl:text>&#60;/table&#62;</xsl:text>
  </xsl:template>

  <xsl:template match="description" mode="pop-up" >
    <xsl:apply-templates select="schedule-shift-description" mode="pop-up" />
  </xsl:template>

  <xsl:template match="schedule-shift-description" mode="pop-up">
    <!-- this was based on the Ent 2.2 source -->
    <xsl:text>&#60;table class=\'hover-schedule\'&#62;</xsl:text>
      <xsl:apply-templates select="coverage" mode="pop-up" />
      <xsl:apply-templates select="team" mode="pop-up" />
      <xsl:apply-templates select="temporary-replacements-header" mode="pop-up" />
      <xsl:apply-templates select="temporaryReplacement" mode="pop-up" />
      <xsl:text>&#60;/table&#62;</xsl:text>
  </xsl:template>

  <xsl:template match="coverage" mode="pop-up">
    <xsl:text>&#60;tr&#62;</xsl:text>
      <xsl:text>&#60;td class=\'header\' colspan=\'3\'&#62;</xsl:text>
        <xsl:apply-templates mode="coverage" />
      <xsl:text>&#60;/td&#62;</xsl:text>
    <xsl:text>&#60;/tr&#62;</xsl:text>
  </xsl:template>

  <xsl:template match="date-range" mode="coverage">
    <xsl:apply-templates select="start" mode="coverage" />
    <xsl:text>&#32;-&#32;</xsl:text>
    <xsl:apply-templates select="end" mode="coverage" />
  </xsl:template>

  <xsl:template match="date-range" mode="daily-schedule">
    <xsl:apply-templates select="start" mode="daily-schedule" />
    <xsl:text>&#32;-&#32;</xsl:text>
    <xsl:apply-templates select="end" mode="daily-schedule" />
  </xsl:template>

  <xsl:template match="date-range" mode="replacement-period">
    <xsl:apply-templates select="start" mode="replacement-period" />
    <xsl:text>&#32;-&#32;</xsl:text>
    <xsl:apply-templates select="end" mode="replacement-period" />
  </xsl:template>

  <xsl:template match="start" mode="daily-schedule">
    <xsl:apply-templates select="time" mode="daily-schedule" />
  </xsl:template>

  <xsl:template match="end" mode="daily-schedule">
    <xsl:apply-templates select="time" mode="daily-schedule" />
  </xsl:template>

  <xsl:template match="time" mode="daily-schedule">
    <xsl:value-of select="normalize-space(.)" />
  </xsl:template>

  <xsl:template match="start" mode="coverage">
    <xsl:apply-templates select="month" mode="javascript" />
    <xsl:text>&#32;</xsl:text>
    <xsl:apply-templates select="day" />
    <xsl:text>&#32;&#40;</xsl:text>
    <xsl:apply-templates select="time" mode="coverage" />
    <xsl:apply-templates select="offset" mode="coverage" />
    <xsl:text>&#41;</xsl:text>
  </xsl:template>

  <xsl:template match="start" mode="replacement-period">
    <xsl:apply-templates select="month" />
    <xsl:text>.&#32;</xsl:text>
    <xsl:apply-templates select="day" />
    <xsl:text>&#32;</xsl:text>
    <xsl:apply-templates select="time" mode="coverage" />
  </xsl:template>

  <xsl:template match="end" mode="coverage">
    <xsl:apply-templates select="month" mode="javascript"/>
    <xsl:text>&#32;</xsl:text>
    <xsl:apply-templates select="day" />
    <xsl:text>&#32;&#40;</xsl:text>
    <xsl:apply-templates select="time" mode="coverage" />
    <xsl:apply-templates select="offset" mode="coverage" />
    <xsl:text>&#41;</xsl:text>
  </xsl:template>

  <xsl:template match="end" mode="replacement-period">
    <xsl:apply-templates select="month" />
    <xsl:text>.&#32;</xsl:text>
    <xsl:apply-templates select="day" />
    <xsl:text>&#32;</xsl:text>
    <xsl:apply-templates select="time" mode="coverage" />
  </xsl:template>

  <xsl:template match="time" mode="coverage">
    <xsl:value-of select="normalize-space(.)" />
  </xsl:template>

  <!-- Suppress the GMT offset information -->
  <xsl:template match="offset" />
  <xsl:template match="offset" mode="coverage"/>

  <xsl:template match="team" mode="pop-up">
    <xsl:text>&#60;tr&#62;</xsl:text>
      <xsl:text>&#60;td class=\'subheader\'&#62;"+LBL_Schedules['DELAY']+"&#60;/td&#62;</xsl:text>
      <xsl:text>&#60;td class=\'subheader\'&#62;"+LBL_Schedules['TYPE']+"&#60;/td&#62;</xsl:text>
      <xsl:text>&#60;td class=\'subheader\'&#62;"+LBL_Schedules['NAME']+"&#60;/td&#62;</xsl:text>
    <xsl:text>&#60;/tr&#62;</xsl:text>
    <xsl:apply-templates mode="pop-up" />
  </xsl:template>

  <xsl:template match="team-name" mode="pop-up">
    <xsl:text>&#60;tr&#62;</xsl:text>
      <xsl:text>&#60;td colspan=\'3\'&#62;</xsl:text>
        <xsl:apply-templates select="." />
      <xsl:text>&#60;/td&#62;</xsl:text>
    <xsl:text>&#60;/tr&#62;</xsl:text>
  </xsl:template>

  <xsl:template match="temporaryReplacement" mode="pop-up">
      <xsl:apply-templates select="replacementPeriod"/>
      <xsl:apply-templates mode="pop-up" />
  </xsl:template>

    <xsl:template match="replacementPeriod" mode="pop-up">
    <xsl:text>&#60;tr&#62;</xsl:text>
      <xsl:text>&#60;td class=\'header\' colspan=\'3\'&#62;</xsl:text>
        <xsl:apply-templates mode="coverage" />
      <xsl:text>&#60;/td&#62;</xsl:text>
    <xsl:text>&#60;/tr&#62;</xsl:text>
  </xsl:template>

  <xsl:template match="temporary-replacements-header" mode="pop-up">
    <xsl:text>&#60;tr&#62;</xsl:text>
      <xsl:text>&#60;td class=\'replacementHeader' colspan=\'3\'&#62;</xsl:text>
        <xsl:apply-templates select="." />
      <xsl:text>&#60;/td&#62;</xsl:text>
    <xsl:text>&#60;/tr&#62;</xsl:text>
  </xsl:template>

  <xsl:template match="replacementContent" mode="pop-up">
    <xsl:text>&#60;tr&#62;</xsl:text>
      <xsl:text>&#60;td&#62;</xsl:text>
         <xsl:apply-templates select="delay" />
      <xsl:text>&#60;/td&#62;</xsl:text>
      <xsl:text>&#60;td&#62;</xsl:text>
        <xsl:apply-templates select="type" />
      <xsl:text>&#60;/td&#62;</xsl:text>
      <xsl:text>&#60;td&#62;</xsl:text>
        <xsl:apply-templates select="vacation-replacement" mode="pop-up" />
      <xsl:text>&#60;/td&#62;</xsl:text>
    <xsl:text>&#60;/tr&#62;</xsl:text>
  </xsl:template>
  
  <xsl:template match="member" mode="pop-up">
    <xsl:text>&#60;tr&#62;</xsl:text>
      <xsl:text>&#60;td&#62;</xsl:text>
         <xsl:apply-templates select="delay" />
      <xsl:text>&#60;/td&#62;</xsl:text>
      <xsl:text>&#60;td&#62;</xsl:text>
        <xsl:apply-templates select="type" />
      <xsl:text>&#60;/td&#62;</xsl:text>
      <xsl:text>&#60;td&#62;</xsl:text>
        <xsl:apply-templates select="name" />
      <xsl:text>&#60;/td&#62;</xsl:text>
    <xsl:text>&#60;/tr&#62;</xsl:text>
  </xsl:template>

  <xsl:template match="hasMoreMembers" mode="pop-up" >
    <xsl:text>&#60;tr&#62;</xsl:text>
      <xsl:text>&#60;td colspan=\'3\'&#62;</xsl:text>
        <xsl:text>...</xsl:text>
      <xsl:text>&#60;/td&#62;</xsl:text>
    <xsl:text>&#60;/tr&#62;</xsl:text>
  </xsl:template>


  <xsl:template match="group-schedules-timeframe-only">
    <xsl:apply-templates select="group-schedules" mode="timeframe-only"/>
  </xsl:template>

  <xsl:template match="group-schedules" mode="monthly-schedule" >
    <xsl:apply-templates select="schedule" mode="monthly-schedule"/>
  </xsl:template>

  <xsl:template match="group-schedules" mode="single-timeframe" >
    <xsl:apply-templates select="schedule" mode="single-timeframe"/>
  </xsl:template>

  <xsl:template match="schedule" mode="monthly-schedule">
    <xsl:apply-templates select="coverage" />
    <xsl:if test="not(team='')">
      &cr;
      <xsl:apply-templates select="team" />
    </xsl:if>
  </xsl:template>

  <xsl:template match="schedule" mode="single-timeframe" >
    <xsl:apply-templates mode="display-all-timeframes"/>
  </xsl:template>

  <xsl:template match="rule-display" mode="display-all-timeframes">
    <xsl:apply-templates mode="single-timeframe" />
  </xsl:template>

  <xsl:template match="coverage">
    <xsl:value-of select="normalize-space(start)" />
    <xsl:text>&#32;-&#32;</xsl:text>
    <xsl:value-of select="normalize-space(end)" />
  </xsl:template>

  <!-- group-timeframe mode is includes the team description -->
  <xsl:template match="group-schedules" mode="group-timeframe" >
    <xsl:apply-templates select="schedule" mode="group-timeframe"/>
  </xsl:template>

  <xsl:template match="schedule" mode="group-timeframe" >
    <xsl:apply-templates select="rule-display" mode="group-timeframe" />
    <xsl:text>&#32;</xsl:text>
    <xsl:apply-templates select="team" />
    <br />
  </xsl:template>

  <!-- timeframe-only mode is used to exclude the team description -->
  <xsl:template match="group-schedules" mode="timeframe-only" >
    <xsl:apply-templates select="schedule" mode="timeframe-only"/>
  </xsl:template>

  <xsl:template match="schedule" mode="timeframe-only" >
    <xsl:if test="position() > 1">
        <xsl:text>, </xsl:text>
    </xsl:if>
    <xsl:apply-templates select="rule-display" mode="group-timeframe" />
  </xsl:template>

  <xsl:template match="rule-display" mode="group-timeframe" >
    <xsl:apply-templates mode="group-timeframe" />
  </xsl:template>
  <!-- we only want the inclusive rules for this display -->
  <!-- The exclusive rules are too complicated to be rendered properly. -->
  <xsl:template match="date-rule-container" mode="group-timeframe" >
    <xsl:apply-templates select="inclusive-rules" mode="group-timeframe" />
  </xsl:template>

  <xsl:template match="date-rule-container" mode="single-timeframe" >
    <xsl:apply-templates select="inclusive-rules" mode="single-timeframe" />
  </xsl:template>

  <xsl:template match="repeating-pattern" mode="group-timeframe" >
    <xsl:apply-templates select="." />
  </xsl:template>

  <xsl:template match="repeating-pattern" mode="single-timeframe" >
    <xsl:call-template name="add-repeating-pattern" />
  </xsl:template>

  <!-- recurring-only mode is used to exclude the team description and one-time schedules -->
  <xsl:template match="group-schedules" mode="recurring-only" >
    <xsl:apply-templates select="schedule" mode="recurring-only"/>
  </xsl:template>

  <xsl:template match="schedule" mode="recurring-only" >
    <xsl:apply-templates select="rule-display/date-rule-container/inclusive-rules/rule-display/repeating-pattern" mode="recurring-timeframe" />
  </xsl:template>

  <xsl:template match="repeating-pattern" mode="recurring-timeframe" >
    <xsl:if test="position() > 1">
        <xsl:text>, </xsl:text>
    </xsl:if>
    <xsl:apply-templates select="." />
  </xsl:template>

  <xsl:template match="repeating-pattern" >
    <xsl:choose>
      <xsl:when test="pattern-name">
        <xsl:apply-templates select="pattern-name" />
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="add-repeating-pattern" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="add-repeating-pattern" >
    <xsl:apply-templates select="init-start" mode="time-only" />
    <xsl:choose>
      <xsl:when test="duration">
        <xsl:apply-templates select="duration" />
      </xsl:when>
      <xsl:otherwise>
        <xsl:text> - </xsl:text>
        <xsl:apply-templates select="init-end" mode="time-only" />
      </xsl:otherwise>
    </xsl:choose>
    <xsl:text>&#32;</xsl:text>
    <xsl:apply-templates select="days" />
  </xsl:template>

  <xsl:template match="date-range-collection" mode="group-timeframe" >
  </xsl:template>

  <xsl:template match="date-range-collection" mode="single-timeframe" >
    <xsl:apply-templates select="ranges" />
  </xsl:template>

  <xsl:template match="date-range-collection" >
    <xsl:value-of select="normalize-space(name)" />
    <xsl:text>&#32;</xsl:text>
    <xsl:apply-templates select="ranges" />
  </xsl:template>

  <xsl:template match="inclusive-rules" mode="group-timeframe" >
    <xsl:apply-templates mode="group-timeframe" />
  </xsl:template>

  <xsl:template match="inclusive-rules" mode="single-timeframe" >
    <xsl:apply-templates mode="single-timeframe" />
  </xsl:template>

  <!-- not used yet -->
  <xsl:template match="exclusive-rules" mode="group-timeframe" >
    <xsl:if test="rule-display" >
      <xsl:text>Excluding: </xsl:text>
      <xsl:apply-templates mode="group-timeframe" />
    </xsl:if>
  </xsl:template>

  <xsl:template match="holiday-description" >
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="holiday-date-range" >
    <xsl:apply-templates select="year"/>
    <xsl:text>/</xsl:text>
    <xsl:apply-templates select="month"/>
    <xsl:text>/</xsl:text>
    <xsl:apply-templates select="day"/>
    <xsl:text>&#32;</xsl:text>
  </xsl:template>

  <xsl:template match="holiday-repeating-pattern" >
    <xsl:choose>
      <xsl:when test="day" >
        <xsl:apply-templates select="month-name"/>
        &space;
        <xsl:apply-templates select="day" mode="simple"/>
        <xsl:text>&#32;</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select="day-position"/>
        &space;
        <xsl:apply-templates select="day-name"/>
        &space;
        <i18n:text>of</i18n:text>
        &space;
        <xsl:apply-templates select="month-name"/>
        <xsl:text>&#32;</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="pattern-name" >
    <xsl:value-of select="normalize-space(.)" />
  </xsl:template>

  <xsl:template match="duration" >
    <xsl:text> Lasting </xsl:text>
    <xsl:apply-templates select="hours"/>
    <xsl:text>:</xsl:text>
    <xsl:apply-templates select="minutes"/>
  </xsl:template>

  <xsl:template match="ranges" >
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="range" >
    <xsl:apply-templates select="start" />
    <xsl:text>&#32;-&#32;</xsl:text>
    <xsl:apply-templates select="end" />
    <xsl:apply-templates select="date" />
  </xsl:template>

  <xsl:template match="start" mode="time-only" >
    <xsl:apply-templates select="time"/>
  </xsl:template>

  <xsl:template match="end" mode="time-only" >
    <xsl:apply-templates select="time"/>
  </xsl:template>

  <xsl:template match="init-start" mode="time-only" >
    <xsl:apply-templates select="time"/>
  </xsl:template>

  <xsl:template match="init-end" mode="time-only" >
    <xsl:apply-templates select="time"/>
  </xsl:template>

  <xsl:template match="start" >
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="end" >
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="device-timeframe">
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="schedule" >
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="rule-display" >
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="date-rule-container" >
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="inclusive-rules" >
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="frequency" >
    <xsl:value-of select="normalize-space(.)" />
    <xsl:text>&#32;</xsl:text>
  </xsl:template>

  <xsl:template match="interval" >
    <xsl:value-of select="normalize-space(.)" />
    <xsl:text>&#32;</xsl:text>
  </xsl:template>

  <xsl:template match="days" >
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="init-start" >
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="init-end" >
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="date" >
    <xsl:apply-templates select="year"/>
    <xsl:text>/</xsl:text>
    <xsl:apply-templates select="month"/>
    <xsl:text>/</xsl:text>
    <xsl:apply-templates select="day"/>
    <xsl:text>&#32;</xsl:text>
  </xsl:template>

  <xsl:template match="time" >
    <xsl:apply-templates select="hour"/>
    <xsl:text>:</xsl:text>
    <xsl:apply-templates select="minute"/>
    <xsl:text>&#32;</xsl:text>
  </xsl:template>

  <xsl:template match="year" >
    <xsl:value-of select="normalize-space(.)" />
  </xsl:template>

  <xsl:template match="month" >
    <xsl:value-of select="normalize-space(.)" />
  </xsl:template>

  <xsl:template match="month" mode="javascript" >
    <xsl:text>"+LBL_Schedules["</xsl:text>
    <xsl:value-of select="normalize-space(.)" />
    <xsl:text>"]+"</xsl:text>
  </xsl:template>

  <xsl:template match="day" >
    <xsl:value-of select="normalize-space(.)" />
    <xsl:text>&#32;</xsl:text>
  </xsl:template>

  <xsl:template match="day" mode="simple">
    <xsl:value-of select="normalize-space(.)" />
  </xsl:template>

  <xsl:template match="month-name" >
    <i18n:text><xsl:value-of select="normalize-space(.)" /></i18n:text>
  </xsl:template>

  <xsl:template match="day-name" >
    <i18n:text><xsl:value-of select="normalize-space(.)" /></i18n:text>
  </xsl:template>

  <xsl:template match="day-position" >
    <i18n:text><xsl:value-of select="normalize-space(.)" /></i18n:text>
  </xsl:template>

  <xsl:template match="hour" >
    <xsl:value-of select="normalize-space(.)" />
  </xsl:template>

  <xsl:template match="minute" >
    <xsl:value-of select="normalize-space(.)" />
  </xsl:template>

  <xsl:template match="hours" >
    <xsl:value-of select="normalize-space(.)" />
  </xsl:template>

  <xsl:template match="minutes" >
    <xsl:value-of select="normalize-space(.)" />
  </xsl:template>

  <xsl:template match="order" >
    <xsl:value-of select="normalize-space(.)" />
  </xsl:template>

  <xsl:template match="delay" >
    <xsl:value-of select="normalize-space(.)" />
  </xsl:template>

  <xsl:template match="type" >
    <xsl:value-of select="normalize-space(.)" />
  </xsl:template>

  <xsl:template match="name" >
    <xsl:value-of select="normalize-space(.)" />
  </xsl:template>

  <xsl:template match="company-name" >
    <xsl:value-of select="normalize-space(.)" />
  </xsl:template>

  <xsl:template match="name[child::replacement]" priority="2">
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="replacement" >
    <xsl:value-of select="normalize-space(.)" />
  </xsl:template>

  <xsl:template match="vacationer" >
    <xsl:text> for (</xsl:text><xsl:value-of select="normalize-space(.)" /><xsl:text>)</xsl:text>
  </xsl:template>

  <xsl:template match="vacation-replacement" >
      <xsl:attribute name="onmouseover">
        <xsl:text>$(this).xToolTip("</xsl:text>
       <xsl:text>&#60;div class='monthly-schedule-vacation-replacement'&#62;</xsl:text>
       <xsl:text>&#60;div class='vacation-replacement-title'&#62;"+LBL_Monthly_Schedules['VACATION_REPLACEMENT']+"&#60;/div&#62;</xsl:text>
       <xsl:apply-templates />
       <xsl:text>&#60;/div&#62;");</xsl:text>
      </xsl:attribute>

      <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="daily-schedule-vacationer" >
    <b><xsl:value-of select="normalize-space(.)" /></b>
  </xsl:template>

  <xsl:template match="daily-schedule-vacationer" mode="pop-up">
    <xsl:text>&#60;b&#62;</xsl:text><xsl:value-of select="normalize-space(.)" /><xsl:text>&#60;/b&#62;</xsl:text>
  </xsl:template>

  <xsl:template match="vacation-replacement-for" >
    <xsl:text> </xsl:text><xsl:value-of select="." /><xsl:text> </xsl:text>
  </xsl:template>

  <!-- not used yet -->
  <xsl:template match="exclusive-rules" >
    <xsl:if test="rule-display" >
      <xsl:text>Excluding: </xsl:text>
      <xsl:apply-templates />
    </xsl:if>
  </xsl:template>

  <xsl:template match="team">
    <xsl:apply-templates />
    <xsl:text>&#32;</xsl:text>
  </xsl:template>

  <xsl:template match="member" >
    <xsl:value-of select="normalize-space(.)" />
    <xsl:if test="position() != last()">
      <xsl:text>,</xsl:text>
    </xsl:if>
  </xsl:template>

  <xsl:template match="holiday-popup">    
    <a>
      <xsl:attribute name="class">details</xsl:attribute>
      <xsl:attribute name="style">cursor: pointer;</xsl:attribute>
      <xsl:attribute name="onclick"><xsl:text>$(this).xDialog(</xsl:text>
        <xsl:text>  '</xsl:text>
        <xsl:value-of select='@label' />
        <xsl:text>', '&lt;ul&gt;</xsl:text>

        <xsl:apply-templates select="holiday-popup-holiday" />

        <xsl:text>  &lt;/ul&gt;');</xsl:text>

      </xsl:attribute>
      <i18n:text>View Holiday List</i18n:text>
    </a>
  </xsl:template>
  <xsl:template match="holiday-popup-holiday">&#60;li&#62;&#60;strong&#62;<xsl:call-template name="escape-apos"><xsl:with-param name="string" select="@title" /></xsl:call-template>&#60;/strong&#62;&#32;<xsl:if test="child::*">(&#32;<xsl:apply-templates/>)</xsl:if>&#60;/li&#62;</xsl:template>

  <xsl:template name="escape-apos">
     <xsl:param name="string" />
     <xsl:choose>
        <xsl:when test='contains($string, "&apos;")'>
           <xsl:value-of select='substring-before($string, "&apos;")' />
           <xsl:text>\'</xsl:text>
           <xsl:call-template name="escape-apos">
              <xsl:with-param name="string" select='substring-after($string, "&apos;")' />
           </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>
           <xsl:value-of select="$string" />
        </xsl:otherwise>
     </xsl:choose>
  </xsl:template>

</xsl:stylesheet>
